==> jc-1.4.0.tar.gz: gnu/java/security/pkcs/PKCS7SignedData.h <==
// public class gnu.java.security.pkcs.PKCS7SignedData

// class file dependencies
// @dep_class 8357d4aa93a8320a gnu_java_security_pkcs_PKCS7SignedData
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_pkcs_PKCS7SignedData_H_
#define _JC_gnu_java_security_pkcs_PKCS7SignedData_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_gnu_java_security_ber_BERReader$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_math_BigInteger$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_gnu_java_security_pkcs_PKCS7SignedData$sub_refs	_jc_gnu_java_security_pkcs_PKCS7SignedData$sub_refs;
typedef struct _jc_gnu_java_security_pkcs_PKCS7SignedData$sub_nonrefs	_jc_gnu_java_security_pkcs_PKCS7SignedData$sub_nonrefs;
typedef struct _jc_gnu_java_security_pkcs_PKCS7SignedData$refs	_jc_gnu_java_security_pkcs_PKCS7SignedData$refs;
typedef struct _jc_gnu_java_security_pkcs_PKCS7SignedData$nonrefs	_jc_gnu_java_security_pkcs_PKCS7SignedData$nonrefs;
typedef struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object	_jc_gnu_java_security_pkcs_PKCS7SignedData$object;

typedef struct _jc_gnu_java_security_pkcs_PKCS7SignedData$fields_struct	_jc_gnu_java_security_pkcs_PKCS7SignedData$fields_struct;
typedef const struct _jc_gnu_java_security_pkcs_PKCS7SignedData$vmethods	_jc_gnu_java_security_pkcs_PKCS7SignedData$vmethods;
typedef const struct _jc_gnu_java_security_pkcs_PKCS7SignedData$vtable	_jc_gnu_java_security_pkcs_PKCS7SignedData$vtable;
typedef const struct _jc_gnu_java_security_pkcs_PKCS7SignedData$vtype	_jc_gnu_java_security_pkcs_PKCS7SignedData$vtype;

// Class fields structure
struct _jc_gnu_java_security_pkcs_PKCS7SignedData$fields_struct {
	struct _jc_gnu_java_security_OID$object	*PKCS7__5fDATA;
	struct _jc_gnu_java_security_OID$object	*PKCS7__5fSIGNED__5fDATA;
	jboolean	DEBUG;
};
extern _jc_gnu_java_security_pkcs_PKCS7SignedData$fields_struct _jc_gnu_java_security_pkcs_PKCS7SignedData$class_fields;

// Constructors
extern void _jc_gnu_java_security_pkcs_PKCS7SignedData$method$_init$3490ea2ddf9a1123(_jc_env *, struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object *, struct _jc_gnu_java_security_ber_BERReader$object *);
extern void _jc_gnu_java_security_pkcs_PKCS7SignedData$method$_init$3887600c17c5e554(_jc_env *, struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object *, struct _jc_java_io_InputStream$object *);

// Virtual methods
extern _jc_object_array *_jc_gnu_java_security_pkcs_PKCS7SignedData$method$getCertificates$39b82b17735f6833(_jc_env *, struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object *);
extern _jc_byte_array *_jc_gnu_java_security_pkcs_PKCS7SignedData$method$getContent$b0006e85f551bab2(_jc_env *, struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object *);
extern struct _jc_gnu_java_security_OID$object *_jc_gnu_java_security_pkcs_PKCS7SignedData$method$getContentType$da50ab16c1416670(_jc_env *, struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object *);
extern struct _jc_object *_jc_gnu_java_security_pkcs_PKCS7SignedData$method$getDigestAlgorithms$c7283efbc1d37f2b(_jc_env *, struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object *);
extern struct _jc_object *_jc_gnu_java_security_pkcs_PKCS7SignedData$method$getSignerInfos$511868dfc48eb85e(_jc_env *, struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object *);
extern struct _jc_java_math_BigInteger$object *_jc_gnu_java_security_pkcs_PKCS7SignedData$method$getVersion$ca61f34d671115e6(_jc_env *, struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_pkcs_PKCS7SignedData$method_info$getCertificates$39b82b17735f6833;
extern _jc_method _jc_gnu_java_security_pkcs_PKCS7SignedData$method_info$getContent$b0006e85f551bab2;
extern _jc_method _jc_gnu_java_security_pkcs_PKCS7SignedData$method_info$getContentType$da50ab16c1416670;
extern _jc_method _jc_gnu_java_security_pkcs_PKCS7SignedData$method_info$getDigestAlgorithms$c7283efbc1d37f2b;
extern _jc_method _jc_gnu_java_security_pkcs_PKCS7SignedData$method_info$getSignerInfos$511868dfc48eb85e;
extern _jc_method _jc_gnu_java_security_pkcs_PKCS7SignedData$method_info$getVersion$ca61f34d671115e6;

// Static methods
extern void _jc_gnu_java_security_pkcs_PKCS7SignedData$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern void _jc_gnu_java_security_pkcs_PKCS7SignedData$method$debug$1e3312c3736b0b51(_jc_env *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_gnu_java_security_pkcs_PKCS7SignedData$vmethods {
	_jc_object_array	*(*getCertificates$39b82b17735f6833)(_jc_env *, struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object *);
	_jc_byte_array	*(*getContent$b0006e85f551bab2)(_jc_env *, struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object *);
	struct _jc_gnu_java_security_OID$object	*(*getContentType$da50ab16c1416670)(_jc_env *, struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object *);
	struct _jc_object	*(*getDigestAlgorithms$c7283efbc1d37f2b)(_jc_env *, struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object *);
	struct _jc_object	*(*getSignerInfos$511868dfc48eb85e)(_jc_env *, struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object *);
	struct _jc_java_math_BigInteger$object	*(*getVersion$ca61f34d671115e6)(_jc_env *, struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object *);
};

// Vtable
struct _jc_gnu_java_security_pkcs_PKCS7SignedData$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_pkcs_PKCS7SignedData$vmethods	gnu_java_security_pkcs_PKCS7SignedData;
};

// Vtype
struct _jc_gnu_java_security_pkcs_PKCS7SignedData$vtype {
	_jc_type			type;
	_jc_gnu_java_security_pkcs_PKCS7SignedData$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_pkcs_PKCS7SignedData$sub_refs {
	struct _jc_java_math_BigInteger$object	*version;
	struct _jc_object	*digestAlgorithms;
	struct _jc_gnu_java_security_OID$object	*contentType;
	_jc_byte_array	*content;
	_jc_object_array	*certificates;
	_jc_object_array	*crls;
	struct _jc_object	*signerInfos;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_pkcs_PKCS7SignedData$refs {
    _jc_gnu_java_security_pkcs_PKCS7SignedData$sub_refs	gnu_java_security_pkcs_PKCS7SignedData;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_pkcs_PKCS7SignedData$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_pkcs_PKCS7SignedData$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_pkcs_PKCS7SignedData$sub_nonrefs	gnu_java_security_pkcs_PKCS7SignedData;
};

// Object instance structure
struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object {
	_jc_gnu_java_security_pkcs_PKCS7SignedData$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_pkcs_PKCS7SignedData$vtype	*vtype;
	_jc_gnu_java_security_pkcs_PKCS7SignedData$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_pkcs_PKCS7SignedData$vtype _jc_gnu_java_security_pkcs_PKCS7SignedData$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_pkcs_PKCS7SignedData, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_pkcs_PKCS7SignedData$class_object;

#endif	/* _JC_gnu_java_security_pkcs_PKCS7SignedData_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/pkcs/PKCS7SignedData.h <==
// public class gnu.java.security.pkcs.PKCS7SignedData

// class file dependencies
// @dep_class 8357d4aa93a8320a gnu_java_security_pkcs_PKCS7SignedData
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_pkcs_PKCS7SignedData_H_
#define _JC_gnu_java_security_pkcs_PKCS7SignedData_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_gnu_java_security_ber_BERReader$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_math_BigInteger$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_gnu_java_security_pkcs_PKCS7SignedData$sub_refs	_jc_gnu_java_security_pkcs_PKCS7SignedData$sub_refs;
typedef struct _jc_gnu_java_security_pkcs_PKCS7SignedData$sub_nonrefs	_jc_gnu_java_security_pkcs_PKCS7SignedData$sub_nonrefs;
typedef struct _jc_gnu_java_security_pkcs_PKCS7SignedData$refs	_jc_gnu_java_security_pkcs_PKCS7SignedData$refs;
typedef struct _jc_gnu_java_security_pkcs_PKCS7SignedData$nonrefs	_jc_gnu_java_security_pkcs_PKCS7SignedData$nonrefs;
typedef struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object	_jc_gnu_java_security_pkcs_PKCS7SignedData$object;

typedef struct _jc_gnu_java_security_pkcs_PKCS7SignedData$fields_struct	_jc_gnu_java_security_pkcs_PKCS7SignedData$fields_struct;
typedef const struct _jc_gnu_java_security_pkcs_PKCS7SignedData$vmethods	_jc_gnu_java_security_pkcs_PKCS7SignedData$vmethods;
typedef const struct _jc_gnu_java_security_pkcs_PKCS7SignedData$vtable	_jc_gnu_java_security_pkcs_PKCS7SignedData$vtable;
typedef const struct _jc_gnu_java_security_pkcs_PKCS7SignedData$vtype	_jc_gnu_java_security_pkcs_PKCS7SignedData$vtype;

// Class fields structure
struct _jc_gnu_java_security_pkcs_PKCS7SignedData$fields_struct {
	struct _jc_gnu_java_security_OID$object	*PKCS7__5fDATA;
	struct _jc_gnu_java_security_OID$object	*PKCS7__5fSIGNED__5fDATA;
	jboolean	DEBUG;
};
extern _jc_gnu_java_security_pkcs_PKCS7SignedData$fields_struct _jc_gnu_java_security_pkcs_PKCS7SignedData$class_fields;

// Constructors
extern void _jc_gnu_java_security_pkcs_PKCS7SignedData$method$_init$3490ea2ddf9a1123(_jc_env *, struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object *, struct _jc_gnu_java_security_ber_BERReader$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_pkcs_PKCS7SignedData$method$_init$3887600c17c5e554(_jc_env *, struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_gnu_java_security_pkcs_PKCS7SignedData$method$getCertificates$39b82b17735f6833(_jc_env *, struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_gnu_java_security_pkcs_PKCS7SignedData$method$getContent$b0006e85f551bab2(_jc_env *, struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object *) _JC_JCNI_ATTR;
extern struct _jc_gnu_java_security_OID$object *_jc_gnu_java_security_pkcs_PKCS7SignedData$method$getContentType$da50ab16c1416670(_jc_env *, struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_java_security_pkcs_PKCS7SignedData$method$getDigestAlgorithms$c7283efbc1d37f2b(_jc_env *, struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_java_security_pkcs_PKCS7SignedData$method$getSignerInfos$511868dfc48eb85e(_jc_env *, struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_gnu_java_security_pkcs_PKCS7SignedData$method$getVersion$ca61f34d671115e6(_jc_env *, struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_pkcs_PKCS7SignedData$method_info$getCertificates$39b82b17735f6833;
extern _jc_method _jc_gnu_java_security_pkcs_PKCS7SignedData$method_info$getContent$b0006e85f551bab2;
extern _jc_method _jc_gnu_java_security_pkcs_PKCS7SignedData$method_info$getContentType$da50ab16c1416670;
extern _jc_method _jc_gnu_java_security_pkcs_PKCS7SignedData$method_info$getDigestAlgorithms$c7283efbc1d37f2b;
extern _jc_method _jc_gnu_java_security_pkcs_PKCS7SignedData$method_info$getSignerInfos$511868dfc48eb85e;
extern _jc_method _jc_gnu_java_security_pkcs_PKCS7SignedData$method_info$getVersion$ca61f34d671115e6;

// Static methods
extern void _jc_gnu_java_security_pkcs_PKCS7SignedData$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_pkcs_PKCS7SignedData$method$debug$1e3312c3736b0b51(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_security_pkcs_PKCS7SignedData$vmethods {
	_jc_object_array	*(*getCertificates$39b82b17735f6833)(_jc_env *, struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getContent$b0006e85f551bab2)(_jc_env *, struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object *) _JC_JCNI_ATTR;
	struct _jc_gnu_java_security_OID$object	*(*getContentType$da50ab16c1416670)(_jc_env *, struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getDigestAlgorithms$c7283efbc1d37f2b)(_jc_env *, struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getSignerInfos$511868dfc48eb85e)(_jc_env *, struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getVersion$ca61f34d671115e6)(_jc_env *, struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_pkcs_PKCS7SignedData$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_pkcs_PKCS7SignedData$vmethods	gnu_java_security_pkcs_PKCS7SignedData;
};

// Vtype
struct _jc_gnu_java_security_pkcs_PKCS7SignedData$vtype {
	_jc_type			type;
	_jc_gnu_java_security_pkcs_PKCS7SignedData$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_pkcs_PKCS7SignedData$sub_refs {
	struct _jc_java_math_BigInteger$object	*version;
	struct _jc_object	*digestAlgorithms;
	struct _jc_gnu_java_security_OID$object	*contentType;
	_jc_byte_array	*content;
	_jc_object_array	*certificates;
	_jc_object_array	*crls;
	struct _jc_object	*signerInfos;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_pkcs_PKCS7SignedData$refs {
    _jc_gnu_java_security_pkcs_PKCS7SignedData$sub_refs	gnu_java_security_pkcs_PKCS7SignedData;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_pkcs_PKCS7SignedData$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_pkcs_PKCS7SignedData$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_pkcs_PKCS7SignedData$sub_nonrefs	gnu_java_security_pkcs_PKCS7SignedData;
};

// Object instance structure
struct _jc_gnu_java_security_pkcs_PKCS7SignedData$object {
	_jc_gnu_java_security_pkcs_PKCS7SignedData$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_pkcs_PKCS7SignedData$vtype	*vtype;
	_jc_gnu_java_security_pkcs_PKCS7SignedData$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_pkcs_PKCS7SignedData$vtype _jc_gnu_java_security_pkcs_PKCS7SignedData$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_pkcs_PKCS7SignedData, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_pkcs_PKCS7SignedData$class_object;

#endif	/* _JC_gnu_java_security_pkcs_PKCS7SignedData_H_ */
